@@ -10,7 +10,7 @@ class SendingClient():
     def __init__(self,server_addr):
         self.server_addr = server_addr
 
-    def send_statement(self,data):
+    def send_xapi_statement(self,data):
         """
         Convert data to the xAPI format, and send it to the LRS
 
