@@ -4,7 +4,8 @@ from thonny import THONNY_USER_DIR, get_workbench
 DEFAULT_PATH = THONNY_USER_DIR+"/LoggingPlugin/"
 DEFAULT_SERVER = 'http://127.0.0.1:8000'
 DEFAULT_STORE = True
-DEFAULT_LOG_IN_CONSOLE = True
+DEFAULT_SEND = False
+DEFAULT_LOG_IN_CONSOLE = False
 VERSION = "0.1.6"
 
 #Dict of options name and default value
@@ -13,6 +14,7 @@ OPTIONS = {
     "server_address" : DEFAULT_SERVER,
     "store_logs" : DEFAULT_STORE,
     "log_in_console" : DEFAULT_LOG_IN_CONSOLE,
+    "send_logs" : DEFAULT_SEND,
 }
 
 #Get the thonny workbench object
